.. _github-stats-3-8-3:

GitHub statistics for 3.8.3 (Feb 14, 2024)
==========================================

GitHub statistics for 2023/11/17 (tag: v3.8.2) - 2024/02/14

These lists are automatically generated, and may be incomplete or contain duplicates.

We closed 18 issues and merged 74 pull requests.
The full list can be seen `on GitHub <https://github.com/matplotlib/matplotlib/milestone/88?closed=1>`__

The following 25 authors contributed 133 commits.

* Allan Haldane
* Antony Lee
* Christoph Hasse
* David Stansby
* dependabot[bot]
* Elliott Sales de Andrade
* Greg Lucas
* hannah
* James Salsman
* Jody Klymak
* Joshua Stevenson
* judfs
* Kyle Sunden
* Matthew Morrison
* Oscar Gustafsson
* Ruth Comer
* Samuel Diebolt
* saranti
* sdiebolt
* Shriya Kalakata
* Stefan
* Steffen Rehberg
* stevezhang1999
* Thomas A Caswell
* Tim Hoffmann

GitHub issues and pull requests:

Pull Requests (74):

* :ghpull:`27790`: Backport PR #27785 on branch v3.8.x (FIX: be careful about communicating with subprocess)
* :ghpull:`27789`: Backport PR #27756 on branch v3.8.x (Add protections against infinite loop in bezier calculations)
* :ghpull:`27785`: FIX: be careful about communicating with subprocess
* :ghpull:`27756`: Add protections against infinite loop in bezier calculations
* :ghpull:`27779`: Manual backport of dependabot cibw upgrades
* :ghpull:`27778`: Backport PR #27773 on branch v3.8.x (MNT: pcolormesh robust underflow)
* :ghpull:`27773`: MNT: pcolormesh robust underflow
* :ghpull:`27777`: Backport PR #27776 on branch v3.8.x (Better document the relation between figure and manager)
* :ghpull:`27776`: Better document the relation between figure and manager
* :ghpull:`27759`: Backport PR #27755 on branch v3.8.x (Allow threads during macos event loop)
* :ghpull:`27755`: Allow threads during macos event loop
* :ghpull:`27742`: Backport PR #27708 on branch v3.8.x (DOC: update colors from colormaps example)
* :ghpull:`27718`: Backport PR #27716 on branch v3.8.x (fix default image format in gtk4 savefig dialog)
* :ghpull:`27716`: fix default image format in gtk4 savefig dialog
* :ghpull:`27697`: Backport PR #27044 on branch v3.8.x (Fix quiver key plot when angles='xy' and/or scale_units='xy')
* :ghpull:`27044`: Fix quiver key plot when angles='xy' and/or scale_units='xy'
* :ghpull:`27691`: Backport PR #27681 on branch v3.8.x (doc: fix Patch.contains_point docstring example)
* :ghpull:`27681`: doc: fix Patch.contains_point docstring example
* :ghpull:`27683`: Backport PR #27670 on branch v3.8.x (Implement macos AppDelegate)
* :ghpull:`27670`: Implement macos AppDelegate
* :ghpull:`27680`: Backport PR #27678 on branch v3.8.x (DOC: selecting individual colors from a colormap)
* :ghpull:`27664`: Backport PR #27581: CI: install German language packs on ubuntu test …
* :ghpull:`27661`: Backport of pr 27647 on v3.8.x
* :ghpull:`27662`: Backport PR #27657 on branch v3.8.x (Fix Numpy 2.0 related test failures)
* :ghpull:`27657`: Fix Numpy 2.0 related test failures
* :ghpull:`27647`: Fix error that occurs when minorticks are on multi-Axes Figure with more than one boxplot
* :ghpull:`27660`: Backport PR #27624 on branch v3.8.x (Prepare for Pytest v8)
* :ghpull:`27624`: Prepare for Pytest v8
* :ghpull:`27636`: Backport PR #27634 on branch v3.8.x (circle: Make deploy stage into a normal step)
* :ghpull:`27622`: Backport PR #27620 on branch v3.8.x (DOC: simplify histogram animation example)
* :ghpull:`27612`: Backport PR #27606 on branch v3.8.x (Pin black version)
* :ghpull:`27606`: Pin black version
* :ghpull:`27598`: Backport PR #27594 on branch v3.8.x (Cleanup viewlims example.)
* :ghpull:`27597`: Backport PR #27595 on branch v3.8.x (Fix is_sorted_and_has_non_nan for byteswapped inputs.)
* :ghpull:`27595`: Fix is_sorted_and_has_non_nan for byteswapped inputs.
* :ghpull:`27586`: Backport PR #27578 on branch v3.8.x (Fix polar labels with negative theta limit)
* :ghpull:`27578`: Fix polar labels with negative theta limit
* :ghpull:`27581`: CI: install German language packs on ubuntu test runners
* :ghpull:`27544`: Backport PR #27527 on branch v3.8.x (FIX: Add macos timers to the main thread)
* :ghpull:`27527`: FIX: Add macos timers to the main thread
* :ghpull:`27537`: Backport PR #27535 on branch v3.8.x (Update ax.legend input types)
* :ghpull:`27535`: Update ax.legend input types
* :ghpull:`27536`: Backport PR #27534 on branch v3.8.x (Clarify AxLine Params)
* :ghpull:`27534`: Clarify AxLine Params
* :ghpull:`27530`: Backport PR #27528 on branch v3.8.x (FIX: Remove runloop execution while waiting for stdin)
* :ghpull:`27528`: FIX: Remove runloop execution while waiting for stdin
* :ghpull:`27510`: Backport PR #27346 on branch v3.8.x (DOC: Show and correct default alignment parameters in text.py)
* :ghpull:`27346`: DOC: Show and correct default alignment parameters in text.py
* :ghpull:`27506`: Backport PR #27504 on branch v3.8.x (DOC: correct return type for axline)
* :ghpull:`27504`: DOC: correct return type for axline
* :ghpull:`27501`: Backport PR #27496 on branch v3.8.x (Bump actions/setup-python from 4 to 5)
* :ghpull:`27496`: Bump actions/setup-python from 4 to 5
* :ghpull:`27484`: Backport PR #27481 on branch v3.8.x (Fixing Pylab documentation in API interface overview)
* :ghpull:`27481`: Fixing Pylab documentation in API interface overview
* :ghpull:`27467`: Manual backport of #27395 on v3.8.x
* :ghpull:`27464`: Backport PR #27316 on branch v3.8.x (DOC: Synchronize LICENSE_STIX files)
* :ghpull:`27316`: DOC: Synchronize LICENSE_STIX files
* :ghpull:`27453`: Backport PR #27434 on branch v3.8.x (FIX: Expand stairs plot-type entry intro (reattempt))
* :ghpull:`27446`: Backport PR #27397 on branch v3.8.x (SpanSelector widget: Improve doc for ``extents``)
* :ghpull:`27397`: SpanSelector widget: Improve doc for ``extents``
* :ghpull:`27444`: Backport PR #27441 on branch v3.8.x (Fix some minor issues with hexbin bins argument)
* :ghpull:`27441`: Fix some minor issues with hexbin bins argument
* :ghpull:`27429`: Backport PR #27411 on branch v3.8.x (DOC: multilevel tick example)
* :ghpull:`27420`: Backport PR #27325 on branch v3.8.x (Fixing Sentence Case on Section Titles in users_explain)
* :ghpull:`27413`: Backport PR #27412 on branch v3.8.x (ci: Block PyQt6 6.6.0 on Ubuntu)
* :ghpull:`27412`: ci: Block PyQt6 6.6.0 on Ubuntu
* :ghpull:`27403`: Backport PR #27386 on branch v3.8.x (Doc: add a "please use dev version" to top of contribute docs)
* :ghpull:`27384`: Backport PR #27377 on branch v3.8.x (TST: Make test_movie_writer_invalid_path locale-agnostic)
* :ghpull:`27377`: TST: Make test_movie_writer_invalid_path locale-agnostic
* :ghpull:`27379`: Backport PR #27376 on branch v3.8.x ([MNT] fix type annotations of ``fignum_exists``)
* :ghpull:`27376`: [MNT] fix type annotations of ``fignum_exists``
* :ghpull:`27369`: Backport PR #27365 on branch v3.8.x ([DOC]: Fix menu example)
* :ghpull:`27365`: [DOC]: Fix menu example
* :ghpull:`27354`: Backport PR #27348 on branch v3.8.x (updated api/animation documentation as per standards)

Issues (18):

* :ghissue:`27437`: [Bug]: PGF backend crashes at program exit after creating a plot
* :ghissue:`27770`: [Bug]: pcolormesh issue with np.seterr(under='raise')
* :ghissue:`27720`: [Bug]: pyplot hangs at pause in sonoma 14.3 with backend MacOSX
* :ghissue:`26316`: [Bug]: quiverkey shows multiple arrows under geographical projection and angle='xy'
* :ghissue:`23178`: [Bug]: ``contains_point()`` does not appear to work?
* :ghissue:`27389`: [Bug]: Warning after update to macOS 14 "WARNING: Secure coding is not enabled for restorable state! Enable secure coding by implementing NSApplicationDelegate.applicationSupportsSecureRestorableState: and returning YES."
* :ghissue:`27645`: [TST] Upcoming dependency test failures
* :ghissue:`26484`: [Bug]: Turning on minor gridlines in a multi-Axes Figure, created with subplots(), that contains >1 boxplot results in a ValueError
* :ghissue:`27596`: [Bug]: Markers with numeric name like CARETLEFT cannot be specified using a cycler
* :ghissue:`25995`: [Bug]: _path.is_sorted is wrong for the non-native byteorder case
* :ghissue:`25568`: [Bug]: unexpected thetalim behavior in polar plot
* :ghissue:`27507`: [Bug]: Argument types for ``handles`` and ``labels`` are too strict for method ``Axes.legend``
* :ghissue:`27503`: [Bug]: Cannot Create lines.AxLine
* :ghissue:`27515`: [Bug]: Python interpreter becomes slow at reading inputs after plotting with matplotlib
* :ghissue:`27345`: [Doc]: text alignment defaults
* :ghissue:`27461`: [Doc]: API interface overview pylab incorrect import statement: from matplotlib.pyplot import *
* :ghissue:`27383`: [Bug]: Error in Hexbin plot in Matplotlib 3.0 onward
* :ghissue:`27358`: [Doc]: Garbled menu widget example output
